# eric7.EricWidgets.EricErrorMessage

Module implementing a specialized error message dialog.

### Global Attributes

_defaultFilters
_filterSettings
_msgHandlerDialog
_msgHandlerMinSeverity
_origMsgHandler

### Classes

EricErrorMessage | Class implementing a specialized error message dialog.

### Functions

editMessageFilters | Module function to edit the list of message filters.
filterMessage | Module function to filter messages.
messageHandler | Module function handling messages.
messageHandlerInstalled | Module function to check, if a message handler was installed.
qtHandler | Module function to install an EricErrorMessage dialog as the global message handler.

## EricErrorMessage

Class implementing a specialized error message dialog.

### Derived from

QErrorMessage

### Class Attributes

None

### Class Methods

None

### Methods

EricErrorMessage | Constructor
editMessageFilters | Public method to edit the list of message filters.
showMessage | Public method to show a message.

### Static Methods

None

#### EricErrorMessage (Constructor)

EricErrorMessage(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### EricErrorMessage.editMessageFilters

editMessageFilters()

Public method to edit the list of message filters.

#### EricErrorMessage.showMessage

showMessage(message, msgType="")

Public method to show a message.

message (str)
  error message to be shown
msgType (str)
  type of the error message

Up

## editMessageFilters

editMessageFilters()

Module function to edit the list of message filters.

Up

## filterMessage

filterMessage(message)

Module function to filter messages.

message (str)
  message to be checked

Return:
  flag indicating that the message should be filtered out

Return Type:
  bool

Up

## messageHandler

messageHandler(msgType, context, message)

Module function handling messages.

msgType (int, QtMsgType)
  type of the message
context (QMessageLogContext)
  context information
message (bytes)
  message to be shown

Up

## messageHandlerInstalled

messageHandlerInstalled()

Module function to check, if a message handler was installed.

Return:
  flag indicating an installed message handler

Return Type:
  bool

Up

## qtHandler

qtHandler(minSeverity)

Module function to install an EricErrorMessage dialog as the global message handler.

minSeverity (int)
  minimum severity of messages to be shown

Return:
  reference to the message handler dialog

Return Type:
  EricErrorMessage

Up